==> swordiedb-0.0.6.tar.gz: swordiedb-0.0.6/swordie_db/__init__.py <==
JOBS = {
    "0": "Beginner",
    "100": "Warrior",
    "110": "Fighter",
    "111": "Crusader",
    "112": "Hero",
    "120": "Page",
    "121": "White Knight",
    "122": "Paladin",
    "130": "Spearman",
    "131": "Dragon Knight",
    "132": "Dark Knight",
    "200": "Magician",
    "210": "Fire Poison",
    "211": "Fire Poison",
    "212": "Fire Poison",
    "220": "Ice Lightning",
    "221": "Ice Lightning",
    "222": "Ice Lightning",
    "230": "Cleric",
    "231": "Priest",
    "232": "Bishop",
    "300": "Archer",
    "310": "Hunter",
    "311": "Ranger",
    "312": "Bowmaster",
    "320": "Cross Bowman",
    "321": "Sniper",
    "322": "Marksman",
    "400": "Rogue",
    "410": "Assassin",
    "411": "Hermit",
    "412": "Night Lord",
    "420": "Bandit",
    "421": "Chief Bandit",
    "422": "Shadower",
    "430": "Blade Recruit",
    "431": "Blade Acolyte",
    "432": "Blade Specialist",
    "433": "Blade Lord",
    "434": "Blade Master",
    "510": "Brawler",
    "511": "Marauder",
    "512": "Buccaneer",
    "520": "Gunslinger",
    "521": "Outlaw",
    "522": "Corsair",
    "501": "Cannon Shooter",
    "530": "Cannoneer",
    "531": "Cannon Trooper",
    "532": "Cannon Master",
    "500": "Maple Brigadier",
    "900": "GM",
    "910": "Super GM",
    "800": "Manager",
    "1000": "Noblesse",
    "1100": "Dawn Warrior",
    "1110": "Dawn Warrior",
    "1111": "Dawn Warrior",
    "1112": "Dawn Warrior",
    "1200": "Blaze Wizard",
    "1210": "Blaze Wizard",
    "1211": "Blaze Wizard",
    "1212": "Blaze Wizard",
    "1300": "Wind Archer",
    "1310": "Wind Archer",
    "1311": "Winder Archer",
    "1312": "Wind Archer",
    "1400": "Night Walker",
    "1410": "Night Walker",
    "1411": "Night Walker",
    "1412": "Night Walker",
    "1500": "Thunder Breaker",
    "1510": "Thunder Breaker",
    "1511": "Thunder Breaker",
    "1512": "Thunder Breaker",
    "2100": "Aran",
    "2110": "Aran",
    "2111": "Aran",
    "2112": "Aran",
    "2200": "Evan",
    "2210": "Evan",
    "2211": "Evan",
    "2212": "Evan",
    "2213": "Evan",
    "2214": "Evan",
    "2215": "Evan",
    "2216": "Evan",
    "2217": "Evan",
    "2218": "Evan",
    "2300": "Mercedes",
    "2310": "Mercedes",
    "2311": "Mercedes",
    "2312": "Mercedes",
    "2400": "Phantom",
    "2410": "Phantom",
    "2411": "Phantom",
    "2412": "Phantom",
    "2700": "Luminous",
    "2710": "Luminous",
    "2711": "Luminous",
    "2712": "Luminous",
    "3000": "Citizen",
    "3100": "Demon Slayer",
    "3110": "Demon Slayer",
    "3111": "Demon Slayer",
    "3112": "Demon Slayer",
    "3101": "Demon Avenger",
    "3120": "Demon Avenger",
    "3121": "Demon Avenger",
    "3122": "Demon Avenger",
    "3200": "Battle Mage",
    "3210": "Battle Mage",
    "3211": "Battle Mage",
    "3212": "Battle Mage",
    "3300": "Wild Hunter",
    "3310": "Wild Hunter",
    "3311": "Wild Hunter",
    "3312": "Wild Hunter",
    "3500": "Mechanic",
    "3510": "Mechanic",
    "3511": "Mechanic",
    "3512": "Mechanic",
    "3600": "Xenon",
    "3610": "Xenon",
    "3611": "Xenon",
    "3612": "Xenon",
    "5100": "Mihile",
    "5110": "Mihile",
    "5111": "Mihile",
    "5112": "Mihile",
    "6100": "Kaiser",
    "6110": "Kaiser",
    "6111": "Kaiser",
    "6112": "Kaiser",
    "6500": "Angelic Buster",
    "6510": "Angelic Buster",
    "6511": "Angelic Buster",
    "6512": "Angelic Buster",
    "10000": "Zero",
    "10100": "Zero",
    "10110": "Zero",
    "10112": "Zero",
    "14000": "Kinesis",
    "14200": "Kinesis",
    "14210": "Kinesis",
    "14211": "Kinesis",
    "14212": "Kinesis",
    "301": "Pathfinder",
    "330": "Pathfinder",
    "331": "Pathfinder",
    "332": "Pathfinder",
    "6400": "Cadena",
    "6410": "Cadena",
    "6411": "Cadena",
    "6412": "Cadena",
    "15000": "Illium",
    "15200": "Illium",
    "15210": "Illium",
    "15212": "Illium",
    "15500": "Ark",
    "15510": "Ark",
    "15511": "Ark",
    "15512": "Ark",
    "15100": "Adele",
    "15110": "Adele",
    "15112": "Adele",
    "15111": "Adele"
}

==> swordiedb-0.1.2.tar.gz: swordiedb-0.1.2/swordie_db/__init__.py <==
"""This is the init file for the package.

Copyright 2020 TEAM SPIRIT. All rights reserved.
Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
This module provides a dictionary mapping all Job IDs to their respective Job names
"""
JOBS = {
    "0": "Beginner",
    "100": "Warrior",
    "110": "Fighter",
    "111": "Crusader",
    "112": "Hero",
    "120": "Page",
    "121": "White Knight",
    "122": "Paladin",
    "130": "Spearman",
    "131": "Dragon Knight",
    "132": "Dark Knight",
    "200": "Magician",
    "210": "Fire Poison",
    "211": "Fire Poison",
    "212": "Fire Poison",
    "220": "Ice Lightning",
    "221": "Ice Lightning",
    "222": "Ice Lightning",
    "230": "Cleric",
    "231": "Priest",
    "232": "Bishop",
    "300": "Archer",
    "310": "Hunter",
    "311": "Ranger",
    "312": "Bowmaster",
    "320": "Cross Bowman",
    "321": "Sniper",
    "322": "Marksman",
    "400": "Rogue",
    "410": "Assassin",
    "411": "Hermit",
    "412": "Night Lord",
    "420": "Bandit",
    "421": "Chief Bandit",
    "422": "Shadower",
    "430": "Blade Recruit",
    "431": "Blade Acolyte",
    "432": "Blade Specialist",
    "433": "Blade Lord",
    "434": "Blade Master",
    "510": "Brawler",
    "511": "Marauder",
    "512": "Buccaneer",
    "520": "Gunslinger",
    "521": "Outlaw",
    "522": "Corsair",
    "501": "Cannon Shooter",
    "530": "Cannoneer",
    "531": "Cannon Trooper",
    "532": "Cannon Master",
    "500": "Maple Brigadier",
    "900": "GM",
    "910": "Super GM",
    "800": "Manager",
    "1000": "Noblesse",
    "1100": "Dawn Warrior",
    "1110": "Dawn Warrior",
    "1111": "Dawn Warrior",
    "1112": "Dawn Warrior",
    "1200": "Blaze Wizard",
    "1210": "Blaze Wizard",
    "1211": "Blaze Wizard",
    "1212": "Blaze Wizard",
    "1300": "Wind Archer",
    "1310": "Wind Archer",
    "1311": "Winder Archer",
    "1312": "Wind Archer",
    "1400": "Night Walker",
    "1410": "Night Walker",
    "1411": "Night Walker",
    "1412": "Night Walker",
    "1500": "Thunder Breaker",
    "1510": "Thunder Breaker",
    "1511": "Thunder Breaker",
    "1512": "Thunder Breaker",
    "2005": "Shade",
    "2500": "Shade",
    "2510": "Shade",
    "2511": "Shade",
    "2512": "Shade",
    "2100": "Aran",
    "2110": "Aran",
    "2111": "Aran",
    "2112": "Aran",
    "2200": "Evan",
    "2210": "Evan",
    "2211": "Evan",
    "2212": "Evan",
    "2213": "Evan",
    "2214": "Evan",
    "2215": "Evan",
    "2216": "Evan",
    "2217": "Evan",
    "2218": "Evan",
    "2300": "Mercedes",
    "2310": "Mercedes",
    "2311": "Mercedes",
    "2312": "Mercedes",
    "2400": "Phantom",
    "2410": "Phantom",
    "2411": "Phantom",
    "2412": "Phantom",
    "2700": "Luminous",
    "2710": "Luminous",
    "2711": "Luminous",
    "2712": "Luminous",
    "3000": "Citizen",
    "3100": "Demon Slayer",
    "3110": "Demon Slayer",
    "3111": "Demon Slayer",
    "3112": "Demon Slayer",
    "3101": "Demon Avenger",
    "3120": "Demon Avenger",
    "3121": "Demon Avenger",
    "3122": "Demon Avenger",
    "3200": "Battle Mage",
    "3210": "Battle Mage",
    "3211": "Battle Mage",
    "3212": "Battle Mage",
    "3300": "Wild Hunter",
    "3310": "Wild Hunter",
    "3311": "Wild Hunter",
    "3312": "Wild Hunter",
    "3500": "Mechanic",
    "3510": "Mechanic",
    "3511": "Mechanic",
    "3512": "Mechanic",
    "3600": "Xenon",
    "3610": "Xenon",
    "3611": "Xenon",
    "3612": "Xenon",
    "5100": "Mihile",
    "5110": "Mihile",
    "5111": "Mihile",
    "5112": "Mihile",
    "6100": "Kaiser",
    "6110": "Kaiser",
    "6111": "Kaiser",
    "6112": "Kaiser",
    "6500": "Angelic Buster",
    "6510": "Angelic Buster",
    "6511": "Angelic Buster",
    "6512": "Angelic Buster",
    "10000": "Zero",
    "10100": "Zero",
    "10110": "Zero",
    "10112": "Zero",
    "14000": "Kinesis",
    "14200": "Kinesis",
    "14210": "Kinesis",
    "14211": "Kinesis",
    "14212": "Kinesis",
    "301": "Pathfinder",
    "330": "Pathfinder",
    "331": "Pathfinder",
    "332": "Pathfinder",
    "6400": "Cadena",
    "6410": "Cadena",
    "6411": "Cadena",
    "6412": "Cadena",
    "15000": "Illium",
    "15200": "Illium",
    "15210": "Illium",
    "15212": "Illium",
    "15001": "Ark",
    "15500": "Ark",
    "15510": "Ark",
    "15511": "Ark",
    "15512": "Ark",
    "15002": "Adele",
    "15100": "Adele",
    "15110": "Adele",
    "15112": "Adele",
    "15111": "Adele",
    "16000": "Hoyoung",
    "16400": "Hoyoung",
    "16410": "Hoyoung",
    "16411": "Hoyoung",
    "16412": "Hoyoung"
}
